==> node-red-contrib-ewelink-copy-1.0.0.tgz: package/src/utils/ewelink-connect.js <==

const EventEmitter = require('events');


module.exports = {
  /**
   * Ready promise.
   * 
   * @param {object} RED The NodeRED instance.
   * @param {object} node The current node.
   * @param {object} config The node configuration.
   */
  async ready(RED, node, config) {
    // Get credentials node
    const credentialsNode = RED.nodes.getNode(config.auth);

    // Check for valid credential node
    if (!credentialsNode) {
      throw new Error('No credentials provided!');
    }

    // Set the node status to 'connecting'
    this.setNodeStatusToConnecting(node);

    credentialsNode.promise = credentialsNode.promise || credentialsNode.connection.login();
    
    return credentialsNode.promise.then(response => {
      // Check for errors in the response
      if (response.error) {
        this.setNodeStatusToDisconnected(node);
        return Promise.reject(response);
      }

      // If we are here everything is great
      this.setNodeStatusToConnected(node);
      return credentialsNode.connection;
    }).catch(error => {
        this.setNodeStatusToDisconnected(node);
        Promise.reject(JSON.stringify(error));
      });
  },

  /**
   * Initialize device node.
   * 
   * @param {object} RED The NodeRED instance.
   * @param {object} node The current node.
   * @param {object} config The node configuration.
   * @param {string} method The method to call on the device.
   * @param {array} params The parameters of the method.
   */
  initializeDeviceNode(RED, node, config, method, params) {
    // Clean up device ID
    const deviceId = config.deviceId ? config.deviceId.trim() : '';

    // Log in to eWeLink
    this.ready(RED, node, config).then(connection => {
      const credentialsNode = RED.nodes.getNode(config.auth);
      // Once logged in we can listen to inputs
      node.on('input', (msg) => {

        // Get method name and build params
        const evaluatedMethod = method || msg.payload.method;
        const evaluatedParams = (typeof params === 'function' ? params(msg) : params) || msg.payload.params || [];
        
        // First parameter should be always the device ID
        evaluatedParams.unshift(deviceId);
        
        // Call dynamically the method
        credentialsNode.connection[evaluatedMethod].apply(credentialsNode.connection, evaluatedParams).then(result => {
          node.send({ payload: result });
        }).catch(error => node.error(error));
      })
    }).catch(error => node.error(error));
  },

  /**
   * Set node status to 'connecting'.
   * 
   * @param {object} node The node which status will be changed.
   */
  setNodeStatusToConnecting(node) {
    node.status({
      fill: 'yellow',
      shape: 'dot',
      text: 'connecting'
    });
  },

  /**
   * Set node status to 'connected'.
   * 
   * @param {object} node The node which status will be changed.
   */
  setNodeStatusToConnected(node) {
    node.status({
      fill: 'green',
      shape: 'dot',
      text: 'connected'
    });
  },

  /**
   * Set node status to 'disconnected'.
   * 
   * @param {object} node The node which status will be changed.
   */
  setNodeStatusToDisconnected(node) {
    node.status({
      fill: 'red',
      shape: 'dot',
      text: 'disconnected'
    });
  },

  async on(RED, node, config, device, callback) {
    // Get credentials node
    const credentialsNode = RED.nodes.getNode(config.auth);
    await this.ready(RED, node, config);
    credentialsNode.emiter = credentialsNode.emiter || new EventEmitter();
    credentialsNode.emiter.on(config.deviceId, callback);
    credentialsNode.socket = credentialsNode.socket || credentialsNode.connection.openWebSocket((data) => {
      credentialsNode.emiter.emit(data['deviceid'], data);
    });
      
  },
}

==> node-red-contrib-ewelink-copy-1.0.1.tgz: package/src/utils/ewelink-connect.js <==

const EventEmitter = require('events');


module.exports = {
  /**
   * Ready promise.
   * 
   * @param {object} RED The NodeRED instance.
   * @param {object} node The current node.
   * @param {object} config The node configuration.
   */
  async ready(RED, node, config) {
    // Get credentials node
    const credentialsNode = RED.nodes.getNode(config.auth);

    // Check for valid credential node
    if (!credentialsNode) {
      throw new Error('No credentials provided!');
    }

    // Set the node status to 'connecting'
    this.setNodeStatusToConnecting(node);

    credentialsNode.promise = credentialsNode.promise || credentialsNode.connection.login();
    
    return credentialsNode.promise.then(response => {
      // Check for errors in the response
      if (response.error) {
        this.setNodeStatusToDisconnected(node);
        return Promise.reject(response);
      }

      // If we are here everything is great
      this.setNodeStatusToConnected(node);
      return credentialsNode.connection;
    }).catch(error => {
        this.setNodeStatusToDisconnected(node);
        Promise.reject(JSON.stringify(error));
      });
  },

  /**
   * Initialize device node.
   * 
   * @param {object} RED The NodeRED instance.
   * @param {object} node The current node.
   * @param {object} config The node configuration.
   * @param {string} method The method to call on the device.
   * @param {array} params The parameters of the method.
   */
  initializeDeviceNode(RED, node, config, method, params) {
    // Clean up device ID
    const deviceId = config.deviceId ? config.deviceId.trim() : '';

    // Log in to eWeLink
    return this.ready(RED, node, config).then(connection => {
      const credentialsNode = RED.nodes.getNode(config.auth);
      // Once logged in we can listen to inputs
      node.on('input', (msg) => {

        // Get method name and build params
        const evaluatedMethod = method || msg.payload.method;
        const evaluatedParams = (typeof params === 'function' ? params(msg) : params) || msg.payload.params || [];
        
        // First parameter should be always the device ID
        evaluatedParams.unshift(deviceId);
        
        // Call dynamically the method
        credentialsNode.connection[evaluatedMethod].apply(credentialsNode.connection, evaluatedParams).then(result => {
          node.send({ payload: result });
        }).then(() => node.send(null, { payload: true })).catch(error => node.error(error));
      })
    }).catch(error => node.error(error));
  },

  /**
   * Set node status to 'connecting'.
   * 
   * @param {object} node The node which status will be changed.
   */
  setNodeStatusToConnecting(node) {
    node.status({
      fill: 'yellow',
      shape: 'dot',
      text: 'connecting'
    });
  },

  /**
   * Set node status to 'connected'.
   * 
   * @param {object} node The node which status will be changed.
   */
  setNodeStatusToConnected(node) {
    node.status({
      fill: 'green',
      shape: 'dot',
      text: 'connected'
    });
  },

  /**
   * Set node status to 'disconnected'.
   * 
   * @param {object} node The node which status will be changed.
   */
  setNodeStatusToDisconnected(node) {
    node.status({
      fill: 'red',
      shape: 'dot',
      text: 'disconnected'
    });
  },

  async on(RED, node, config, device, callback) {
    // Get credentials node
    const credentialsNode = RED.nodes.getNode(config.auth);
    await this.ready(RED, node, config);
    credentialsNode.emiter = credentialsNode.emiter || new EventEmitter();
    credentialsNode.emiter.on(config.deviceId, callback);
    credentialsNode.socket = credentialsNode.socket || credentialsNode.connection.openWebSocket((data) => {
      credentialsNode.emiter.emit(data['deviceid'], data);
    });
      
  },
}
